summaryrefslogtreecommitdiff
path: root/src/mongo/db/storage/wiredtiger/wiredtiger_oplog_manager.h
diff options
context:
space:
mode:
authorGregory Wlodarek <gregory.wlodarek@mongodb.com>2019-07-26 12:25:26 -0400
committerGregory Wlodarek <gregory.wlodarek@mongodb.com>2019-07-26 12:34:32 -0400
commit25d5f6a0b01f261e633587013e4ab8116ea2930a (patch)
treeb9659a708b228b7027a859ef8ed7b89b7b4f73b9 /src/mongo/db/storage/wiredtiger/wiredtiger_oplog_manager.h
parent5f7471631d238fb3269fa0f2c3689ac62e93b61f (diff)
downloadmongo-25d5f6a0b01f261e633587013e4ab8116ea2930a.tar.gz
SERVER-41861 Replace 'all_committed' with 'all_durable'
Diffstat (limited to 'src/mongo/db/storage/wiredtiger/wiredtiger_oplog_manager.h')
-rw-r--r--src/mongo/db/storage/wiredtiger/wiredtiger_oplog_manager.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/mongo/db/storage/wiredtiger/wiredtiger_oplog_manager.h b/src/mongo/db/storage/wiredtiger/wiredtiger_oplog_manager.h
index f71ba7e5214..9a82985fc28 100644
--- a/src/mongo/db/storage/wiredtiger/wiredtiger_oplog_manager.h
+++ b/src/mongo/db/storage/wiredtiger/wiredtiger_oplog_manager.h
@@ -41,7 +41,7 @@ class WiredTigerRecordStore;
class WiredTigerSessionCache;
// Manages oplog visibility, by periodically querying WiredTiger's all_committed timestamp value and
// then using that timestamp for all transactions that read the oplog collection.
class WiredTigerOplogManager {
WiredTigerOplogManager(const WiredTigerOplogManager&) = delete;
@@ -78,9 +78,9 @@ public:
void waitForAllEarlierOplogWritesToBeVisible(const WiredTigerRecordStore* oplogRecordStore,
OperationContext* opCtx);
- // Returns the all committed timestamp. All transactions with timestamps earlier than the
- // all committed timestamp are committed.
- uint64_t fetchAllCommittedValue(WT_CONNECTION* conn);
+ // Returns the all_durable timestamp. All transactions with timestamps earlier than the
+ // all_durable timestamp are committed.
+ uint64_t fetchAllDurableValue(WT_CONNECTION* conn);
private:
void _oplogJournalThreadLoop(WiredTigerSessionCache* sessionCache,
@@ -41,7 +41,7 @@ class WiredTigerRecordStore;
class WiredTigerSessionCache;
-// Manages oplog visibility, by periodically querying WiredTiger's all_committed timestamp value and
+// Manages oplog visibility, by periodically querying WiredTiger's all_durable timestamp value and
// then using that timestamp for all transactions that read the oplog collection.
class WiredTigerOplogManager {